#
# spec file for package quassel
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define realver 0.14.0
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           quassel
Version:        0.14.0
Release:        1.5
Summary:        Distributed IRC client
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Productivity/Networking/IRC
URL:            https://quassel-irc.org/
Source:         http://%{name}-irc.org/pub/%{name}-%{realver}.tar.bz2
Source1:        service.%{name}core
Source2:        sysconfig.%{name}core
Source3:        logrotate.%{name}core
Source5:        quassel-rpmlintrc
BuildRequires:  boost-devel
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf5-filesystem
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5NotifyConfig)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(LibsnoreQt5) >= 0.7
BuildRequires:  cmake(Qca-qt5)
BuildRequires:  cmake(Qt5Core) >= 5.5.0
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5WebEngine)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(dbusmenu-qt5)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(zlib)
%{?systemd_requires}

%description
Quassel IRC is a distributed IRC client, meaning that one (or
multiple) client(s) can attach to and detach from a central core --
much like the combination of GNU Screen and a text-based IRC client
such as WeeChat, but graphical.

%package mono
Summary:        Standalone client for the Quassel IRC client
Group:          Productivity/Networking/IRC
Requires:       %{name}-base = %{version}
Requires:       libqt5_sql_backend
Recommends:     libQt5Sql5-sqlite
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
Provides:       %{name}_ui = %{version}

%description mono
Quassel IRC is a distributed IRC client, meaning that one (or
multiple) client(s) can attach to and detach from a central core --
much like the combination of GNU Screen and a text-based IRC client
such as WeeChat, but graphical.

This is the quassel standalone client.

%package client
Summary:        KDE client for the Quassel IRC client
Group:          Productivity/Networking/IRC
Requires:       %{name}-base = %{version}
Requires:       update-alternatives
Requires(post): update-alternatives
Provides:       %{name}_ui = %{version}

%description client
Quassel IRC is a distributed IRC client, meaning that one (or
multiple) client(s) can attach to and detach from a central core --
much like the combination of GNU Screen and a text-based IRC client
such as WeeChat, but graphical.

This is the quassel KDE client only.

%package client-qt5
Summary:        Qt5 client for the Quassel IRC client
Group:          Productivity/Networking/IRC
Requires:       %{name}-base = %{version}
Requires:       update-alternatives
Requires(post): update-alternatives
Provides:       %{name}_ui = %{version}

%description client-qt5
Quassel IRC is a distributed IRC client, meaning that one (or
multiple) client(s) can attach to and detach from a central core --
much like the combination of GNU Screen and a text-based IRC client
such as WeeChat, but graphical.

This is the quassel Qt5 client only

%package core
Summary:        Core program for the Quassel IRC client
Group:          Productivity/Networking/IRC
Requires:       libqt5_sql_backend
Requires:       logrotate
Requires(pre):  %fillup_prereq
Requires(pre):  shadow
Recommends:     libqt5-sql-sqlite

%description core
Quassel IRC is a distributed IRC client, meaning that one (or
multiple) client(s) can attach to and detach from a central core --
much like the combination of GNU Screen and a text-based IRC client
such as WeeChat, but graphical.

This is the core only.

%package base
Summary:        Base files for the Quassel IRC client
Group:          Productivity/Networking/IRC
Requires:       %{name}_ui = %{version}

%description base
Quassel IRC is a distributed IRC client, meaning that one (or
multiple) client(s) can attach to and detach from a central core --
much like the combination of GNU Screen and a text-based IRC client
such as WeeChat, but graphical.

This contains common parts shared by %{name} and %{name}-client.

%prep
%autosetup -p1 -n %{name}-%{realver}

%build
FAKE_BUILDDATE=$(LC_ALL=C date -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/common/quassel.cpp
FAKE_BUILDTIME=$(LC_ALL=C date -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/common/quassel.cpp

%cmake_kf5 -d build -- -DUSE_QT5=ON -DWITH_WEBENGINE=ON -DWITH_KDE=ON -DENABLE_SHARED=OFF
%cmake_build
cd ..
%cmake_kf5 -d build-qt5 -- -DUSE_QT5=ON -DWITH_WEBENGINE=ON -DWITH_KDE=OFF -DENABLE_SHARED=OFF
%cmake_build

%install
%kf5_makeinstall -C build

# Allow client qt5/kde co-install
mv %{buildroot}%{_bindir}/quasselclient %{buildroot}%{_bindir}/quasselclient-kde
install build-qt5/quasselclient %{buildroot}%{_bindir}/quasselclient-qt5
# Alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/quasselclient
ln -sf %{_sysconfdir}/alternatives/quasselclient %{buildroot}%{_bindir}/quasselclient

%fdupes %{buildroot}/%{_prefix}
install -d -m 755 %{buildroot}%{_localstatedir}/lib/%{name}core
install -d -m 755 %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/quasselcore.service
# Provide SUSE policy symlink /usr/sbin/rcFOO -> service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcquasselcore
install -D -m 644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.quasselcore
install -d -m 751 %{buildroot}%{_localstatedir}/log/%{name}
install -D -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}core

# actions svg icon dir is named incorrectly as 'action'
if [ -d %{buildroot}%{_datadir}/icons/hicolor/scalable/action ]; then
    mv %{buildroot}%{_datadir}/icons/hicolor/scalable/action %{buildroot}%{_datadir}/icons/hicolor/scalable/actions
fi

# rewrite env shebang on scripts to normal shebang
sed -i '1{
    s,^#!%{_bindir}/env  *bash *$,#!/bin/bash,
    s,^#!%{_bindir}/env  *\([^ ]*\) *$,#!%{_bindir}/\1,
}' %{buildroot}%{_datadir}/%{name}/scripts/*

%pre core
%{_bindir}/getent group %{name}core >/dev/null || %{_sbindir}/groupadd -r %{name}core
%{_bindir}/getent passwd %{name}core >/dev/null || %{_sbindir}/useradd -r -d %{_localstatedir}/lib/%{name}core \
    -s /bin/false -c "%{name}core daemon" -g %{name}core %{name}core
%service_add_pre quasselcore.service

%post core
%{fillup_only -n quasselcore}
%service_add_post quasselcore.service

%preun core
%service_del_preun quasselcore.service

%postun core
%service_del_postun quasselcore.service

%post client
update-alternatives --install %{_bindir}/quasselclient quasselclient %{_bindir}/quasselclient-kde 20

%postun client
if [ $1 -eq 0 ] ; then
    update-alternatives --remove quasselclient %{_bindir}/quasselclient-kde
fi

%post client-qt5
update-alternatives --install %{_bindir}/quasselclient quasselclient %{_bindir}/quasselclient-qt5 10

%postun client-qt5
if [ $1 -eq 0 ] ; then
    update-alternatives --remove quasselclient %{_bindir}/quasselclient-qt5
fi

%files mono
%doc AUTHORS ChangeLog README.md
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}

%files client
%doc AUTHORS ChangeLog README.md
%{_bindir}/%{name}client-kde
%ghost %{_sysconfdir}/alternatives/quasselclient
%{_bindir}/%{name}client

%files client-qt5
%doc AUTHORS ChangeLog README.md
%{_bindir}/%{name}client-qt5
%ghost %{_sysconfdir}/alternatives/quasselclient
%{_bindir}/%{name}client

%files core
%doc AUTHORS ChangeLog README.md
%{_bindir}/%{name}core
%{_sbindir}/rc%{name}core
%{_unitdir}/%{name}core.service
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}core
%attr(-,%{name}core,%{name}core) %dir %{_localstatedir}/lib/%{name}core
%attr(-,%{name}core,%{name}core) %dir %{_localstatedir}/log/%{name}
%{_fillupdir}/sysconfig.%{name}core

%files base
%license COPYING
%{_datadir}/%{name}
%{_datadir}/applications/%{name}client.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/knotifications5/%{name}.notifyrc

%changelog
* Tue Apr 12 2022 Cronfox <cronfox@erinn.network>
- Update to 0.14.0
  * Database schema format change, no downgrade possible!
  * Don't silently fall back to unencrypted client/core communication if certificate cannot be loaded
  * Properly escape LDAP usernames to prevent injection or bypassing authentication
  * Strip format codes in ignore list rules (this might affect pre-existing rules)
  * Support many more features of IRCv3
  * Improve window handling under Wayland
  * Support the HAProxy protocol
  * Provide a daemon providing Prometheus metrics
  * Deprecate local highlight settings (prefer synced ones instead)
  * Improve configuration of SASL PLAIN and EXTERNAL
  * Add button for strike-through format
  * Allow choosing the account to connect to via command-line option
  * Make database schema migration more robust
  * Make backlog fetch more efficient, allow for fetch-on-demand
  * Make syncing and other aspects of the core/client protocol more efficient
  * Many smaller fixes
  * Improve log output, documentation and UI help
  * Update translations, bundled iconsets and application icons
- Added new BuildRequires boost-devel: New build dependency.
- Added new Require update-alternatives: Fixing missing in post/pre.
- Change logrotate config: Fix permission problem.
- Dropped patches:
  * 0001-common-Disable-enum-type-stream-operators-for-Qt-5.1.patch: Upstream support Qt 5.15.
  * quassel-set-required-libs-and-flags.patch: Remove Qt4 support.
* Mon Nov 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Wed Aug 26 2020 Antonio Larrosa <alarrosa@suse.com>
- Move quassel.pid from /var/run to /run
* Mon Jan 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with Qt 5.14:
  * 0001-common-Disable-enum-type-stream-operators-for-Qt-5.1.patch
* Fri Apr 26 2019 mvetter@suse.com
- bsc#1130588: Require shadow instead of old pwdutils
* Mon Feb 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13.1:
  * Fix backlog message fetching that was broken when using Qt4
  * Improve output to syslog
  * Make upgrading the database schema more robust in case of interruption
  * Fix alignment of buttons in the input widget
  * Fix bug where the nicklist would be hidden on first start
  * Allow configuring the listen addresses for the built-in identd (--ident-listen)
  * Honor core options even if it was just configured via environment variables
  * Fix syncing of auto reconnect retries in network settings
  * Update translations
* Tue Jan  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add ldap dependency so the feature is compiled too
* Thu Nov 22 2018 Dirk Mueller <dmueller@suse.com>
- update to 0.13.0 (bsc#1122572):
  * no dedicated changelog available, final release
* Fri Oct 19 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13-rc2:
  * Many stability tweaks to fix issues reported against the rc1
* Thu Aug 23 2018 rkitover@gmail.com
- Fix systemd ordering cycle in quasselcore.service
* Tue Jul 31 2018 tchvatal@suse.com
- Do not ship quassel.SuSEfirewall2 as firewalld has the config
  within its general package
* Tue Jul 31 2018 tchvatal@suse.com
- Version update to 0.13-rc1:
  * New branding, more modern icons (from the Breeze icon theme)
  * Better support for icon themes
  * Many UI improvements
  * Support for many IRCv3 features, including the display of modern formatting codes
  * Functionality such as highlights and chat activity tracking move into the core to help mobile clients to be more efficient
  * Support for containerization, i.e. config-less core
  * Optional authentication via LDAP
  * Database improvements, including support for 64 bit IDs and timestamps, and performance tweaks
  * For more see ChangeLog
- Drop merged patch Fix-build-with-Qt5.11.patch
* Wed Jul 11 2018 rkitover@gmail.com
- Fix the rpmlint warning env-script-interpreter by rewriting the
  [#]!/usr/bin/env shebang in the scripts in /usr/share/quassel/scripts .
* Wed Jun 27 2018 rkitover@gmail.com
- Change quasselcore.service to start after `default.target` instead of
  `network.target` as the PostgreSQL backend may not be available during
  startup otherwise. bsc#1102568
* Fri Jun 22 2018 wbauer@tmo.at
- Add Fix-build-with-Qt5.11.patch to fix build with Qt 5.11
* Fri May 11 2018 mchandras@suse.de
- Add new QUASSELCORE_PORT sysconfig variable to allow users to change
  the default Quassel Core TCP port.
* Mon Apr 30 2018 jengelh@inai.de
- Trim bias and filler wording from descriptions.
- Stop ignoring errors from useradd/groupadd.
* Wed Apr 25 2018 tchvatal@suse.com
- Version update to 0.12.4:
  * Various small fixes
  * Implement custom deserializer to add our own sanity checks (bsc#1090495
    CVE-2018-1000178)
  * Reject clients that attempt to login before the core is configured
    (bsc#1090495 CVE-2018-1000179)
- Rebase patch quassel-set-required-libs-and-flags.patch
- Switch from qt5webkit to webengine
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Aug 25 2016 tchvatal@suse.com
- Reenable translations that disappeared at some point of time
* Fri May 27 2016 tchvatal@suse.com
- Reduce pc files to only those that are really needed
* Mon May  2 2016 tchvatal@suse.com
- Version update to 0.12.4:
  * Various small fixes
  * Fix for core crash from client handshake data bnc#978002 CVE-2016-4414
* Fri Feb 12 2016 javier@opensuse.org
- Update to 0.12.3
  * Fix activity filters when selecting buffers in custom ChatViews
  * Fix default shortcuts when integrated with KDE Frameworks
  * Introduce support for Appveyor CI (automated Windows builds)
  * Support SnoreNotify 0.7
  * Various cleanups and performance improvements
  * Various build system fixes
  * Channel keys are again remembered between syncs
  * Support for Qt 5.5
  * Network (re)connection fixes
  * Fix possible message loss when running multiple core users on a psql database
  * Command line option for specifying SSL certificates and keys
  * Many smaller fixes
- Rebased quassel-set-required-libs-and-flags.patch
- Removed patches that have been merged upstream
  * CVE-2015-8547.patch
  * Fix-build-with-Qt-5.5.patch
  * Fix-rejoining-parted-channels.patch
- Updated spec:
  * main.cpp no longer contains __DATE__/__TIME__
  * CMakeLists now requires snorenotify-qt5-devel >= 0.7
* Sun Feb  7 2016 tchvatal@suse.com
- Allow building kde and non-kde based quassel version
- Move quasselclient desktop to base so both variants don't have to
  rename the file
- Introduce quasselclient-qt5 subpackage
- Use update-alternatives to switch between kde/qt5 versions
* Mon Dec 14 2015 tchvatal@suse.com
- Apply patch for bnc#958928 CVE-2015-8547:
  * CVE-2015-8547.patch
* Sun Nov 15 2015 vbabka@suse.com
- Add Fix-rejoining-parted-channels.patch: Fixes upstream issue
  http://bugs.quassel-irc.org/issues/1369 where parted channels
  are rejoined after reconnecting.
* Fri Oct  9 2015 hrvoje.senjan@gmail.com
- Added Fix-build-with-Qt-5.5.patch (boo#949489)
* Sat Jul  4 2015 hrvoje.senjan@gmail.com
- Add quassel-set-required-libs-and-flags.patch: Set the correct
  libraries and compiler flags in order to use qglobal.h in
  check_cxx_source_compiles function
- Drop quassel-disable-ssl-check.patch
* Fri Jul  3 2015 tchvatal@suse.com
- Add patch to fix/disable SSL check in cmakelists.txt:
  * quassel-disable-ssl-check.patch
* Wed May  6 2015 tittiatcoke@gmail.com
- Move the notifyrc file to the base package, so that both the mono
  and client subpackages can use it. Without this file there are
  no notifications.
* Wed May  6 2015 tchvatal@suse.com
- Version bump to 0.12.2 bnc#928728:
  * Fix PostgreSQL not re-initializing after reconnect (raising CVE-2013-4422
    from the dead)
  * Remove warning on startup due to a change in Kdelibs4ConfigMigrator
  * Emergency fix for behavior change in Qt5's psql driver regarding timezones
* Tue Apr 21 2015 tchvatal@suse.com
- Deprecate realver as it is not used now again
* Mon Apr 20 2015 tittiatcoke@gmail.com
- Update to 0.12.0 final
  * Remote password change
  * Core connection improvements
  * Build system improvements
  * PostgreSQL connection improvements
  * Improve Qt5 support
  * Translation updates
* Sun Mar 29 2015 tchvatal@suse.com
- Version bump to 0.12-rc1:
  * Core hashing algorithm update
  * Proper message splitting on multi-byte encodings/encryption
  * Updated DB schema, no downgrade possible
* Fri Mar  6 2015 tchvatal@suse.com
- Version bump to 0.12-beta1:
  * Various fixes all around
  * Add support for KF5 so build with its integration
- Reenable qca2 crypto
- Enable snorenotify support
* Thu Jan  8 2015 dimstar@opensuse.org
- Add hicolor-icon-theme BuildRequires and add call to
  icon_theme_cache_post/postun.
* Sun Oct 19 2014 tchvatal@suse.com
- Base us on Qt5 build - currently no direct KF5 integration
- Version bump to 0.11:
  * New build requirements:
  - C++11 capable compiler (gcc 4.7+, clang 3.3+, MSVC 2013+)
  - cmake 2.8.9+
  * Full support for Qt 5.2+ in addition to Qt 4.6+
  * Completely revamp the build system, making use of "new" CMake features
  * Fix buffer hotlist sorting
  * Split CTCP messages if they're too long
  * Make database problems more obvious
  * Fix backlog loading for QuasselDroid
  * Properly save the toolbar state on Mac OSX
  * Fix a crash with KDE's network detection
  * Various other fixes
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Wed Mar 26 2014 herbert@graeber-clan.de
- Update to 0.10.0
  * Refactor lots of the protocol and connection code
  * Introduce connection probing for reliably negotiating protocol features
  * Introduce the new DataStream protocol with streaming compression
  * Option for forcing the core to only accept SSL connections
  * Support for the Snore notification backend
  * Allow searching the web for selected text
  * Connection-related fixes
  * Allow for hiding inactive networks
  * Enable line wrap in the input field
  * Show backlog messages in the Chat Monitor
  * Remove SSL protocol selection, always use auto-negotiation for best
    results
  * Highlight rules are now case-insensitive by default
  * New and updated translations
  * Bump inxi version (for /sysinfo)
  * Use the raster rendering engine by default on OSX (should improve
    performance)
* Fri Mar 14 2014 tittiatcoke@gmail.com
- Cleanup buildrequires and buildrecommends
* Wed Jan  8 2014 speilicke@suse.com
- Add back /etc/sysconfig/quasselcore (bnc#849850)
* Sat Dec  7 2013 cgiboudeaux@gmx.com
- Update to 0.9.2
  * Don't crash if /topic contains newlines.
  * Fix SSL-related issues.
  * Fix Phonon notifications not playing sound.
  * Pingout if connection drops during SASL auth phase.
  * Prevent messages from being sent to status buffers.
  * Make sure manipulated/buggy clients cannot access backlog of other core users.
  * Fix context menu issues.
* Tue Nov  5 2013 speilicke@suse.com
- Fix quasselcore.service, EnvironmentFile belongs into [Service]
  section and use ${FOO} rather than $FOO for proper expansion (Check
  https://fedoraproject.org/wiki/Packaging%%3aSystemd#EnvironmentFiles_and_support_for_.2Fetc.2Fsysconfig_files)
  (bnc#849850)
* Mon Oct 14 2013 tchvatal@suse.com
- Utilize the unit file rather than old initscript
* Sun Oct 13 2013 herbert@graeber-clan.de
- Version bump to 0.9.1 (no official changelog available):
  * Important update for PostgreSQL users, preventing database
    corruption. (bnc#845511)
  * Fixes related to key handling for encrypted channels.
  * Other fixes.
* Fri Aug  9 2013 tchvatal@suse.com
- Version bump to 0.9.0:
  * Halfop support
  * Channel-specific highlights
  * Support for intermediate CA certificates
  * Support the DockManager interface
  * OSX Notification Center support
  * DH1080 key exchange
  * SASL EXTERNAL support
  * Improvements for Retina displays on OSX
  * Supporting to start minimized to tray
  * Rudimentary support for Qt5 (obsolete again because upstream changed too much)
  * Refactor of SignalProxy, network and protocol code
  * First pieces of the coming protocol abstraction
  * Build system improvements
  * Various bugfixes
  * New and updated translations
  * Reformatted ALL the source code
* Fri Jul  6 2012 dmueller@suse.com
- readd group fields for older distros
* Wed Mar 21 2012 herbert@graeber-clan.de
- fix names of some renamed icons
* Tue Mar 20 2012 herbert@graeber-clan.de
- update to version 0.8.0
  * Add support for syslog request
  * Make TAB completion keyboard shortcut configurable
  * /showkey command for blowfish encryption
  * Keyboard navigation: shortcut for hiding the current buffer
  * oidentd support
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sun Oct  9 2011 toddrme2178@gmail.com
- Added dbusmenu-qt buildrequires
- Removed redundant or incorrect provides (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Thu Sep 29 2011 herbert@graeber-clan.de
- update to version 0.7.3 (securtity bugfix release)
  * Some CTCP requests triggered a bug in the parser
  * Core crashed after deleting a Network without disconnecting
    the Network first
* Sun Apr  3 2011 herbert@graeber-clan.de
- update to version 0.7.2
  * show notices in current buffer by default
  * despammificating the pglog. This is done by switching from EAFP to LBYL
  * Reworking handling of Prepared Queries in PostgreSQL (Quasselcore should
    now survive PG restarts)
  * Don't have CTCP ignore rules apply to ACTIONs
  * Some smaller fixes
* Sat Mar  5 2011 herbert@graeber-clan.de
- replace __DATE__ and __TIME__ by quassel.changes change time to
  make buildcompare working better
* Tue Sep 21 2010 herbert@graeber-clan.de
- update to version 0.7.1
  * fix possible DoS over CTCP
* Thu Sep 16 2010 herbert@graeber-clan.de
- update to version 0.7.0 final
- enable dbusmenu support when available
* Sat Aug 28 2010 herbert@graeber-clan.de
- update to version 0.7-rc1
- require libca2-devel for ncryption support
* Sun Aug 15 2010 herbert@graeber-clan.de
- update to version 0.7-beta1
  * Fullscreen mode (F11)
  * CTCP CLIENTINFO support
  * Shortcuts for navigation between chats (Alt+Left/Right/Up/Down)
  * Add blowfish encryption (/setkey and /delkey; needs QCA2)
  * Shortcut editing for all platforms (!KDE)
  * Improved handling of invites
  * New tray icon for highlights
  * Global away
  * Emacs-style keybindings for the input line
  * Improved markerline behavior
  - Allow manual setting (Ctrl+R)
  - Provide shortcut for jumping to the markerline (Ctrl+K)
  * New languages: pt, ja
  * Many bugfixes
* Wed Apr 21 2010 herbert@graeber-clan.de
- update to version 0.6.1
  * bug fixes
* Thu Apr 15 2010 herbert@graeber-clan.de
- update to version 0.6.0
  * Completely reworked client/core connection featuring the long-awaited
    reconnection and Solid support as well as a streamlined UI
  * Support for the new DBus-based system tray of KDE and, in some distros,
    Gnome (StatusNotifier spec)
  * Improved notification handling
  * Support for inputting formatted (colored/bold/...) text
  * SASL auth support (replaces NickServ e.g. in Freenode)
  * Several new languages and improved translations for alreay existing ones
  * Build system improvements
* Mon Mar  8 2010 herbert@graeber-clan.de
- require libqtl4_sql_backend and recommend libqt4-sql-sqlite instead of requiring
  it for quasselcore and quassel-mono
- save output of quasselcore daemon in /var/log/quassel
* Thu Mar  4 2010 herbert@graeber-clan.de
- update to version 0.6-rc1
* Tue Jan 19 2010 herbert@graeber-clan.de
- update to version 0.5.2
* Wed Nov 25 2009 herbert@graeber-clan.de
- update to version 0.5.1
* Fri Oct 16 2009 herbert@graeber-clan.de
- update to version 0.5.0
* Fri Oct  2 2009 herbert@graeber-clan.de
- update to version 0.5rc2
* Wed Sep 16 2009 herbert@graeber-clan.de
- fix requires
* Mon Sep  7 2009 herbert@graeber-clan.de
- remove the kde4 prefix from packages
* Fri Sep  4 2009 herbert@graeber-clan.de
- chown quasselcode.quasselcore /var/lib/quasselcore on installation,
  so that the database can be updated properly
* Sun Aug 30 2009 herbert@graeber-clan.de
- update to version 0.5rc1
  * Sort nicklist (and tabcomplete) by most-recently-used
  * Add a multiline write line with a toogle button like Chatzilla
  * /exec commands
  * Tab completion should show list of possible matches
  * Rework styling settings
  * Please add notifications for pms even when quassel is focused.
  * automatically connect/disconnect on network status changes (w/ KDE)
  * regain primary nick when free again
  * Meta-Buffer: Highlighted Messages
  * SSL Certificate collecting method
* Wed May 27 2009 herbert@graeber-clan.de
- Update to version 0.4.2
- Removed the support to change user and group for the quasselcore daemon
- Use a group named quasselcore instead of daemon
- Use 127.0.0.1 as default listen address. Hostnames are not allowed
- Fix creation of initial log file
* Tue May 26 2009 herbert@graeber-clan.de
- Put kde4_runtime_requires macro into the right subpackages
- Quasselcore requires logrotate
- Move log file into its own folder
- Mark logrotate config file as "noreplace"
- Add rpmlintrc file to make rpmlint happy
* Mon May 25 2009 herbert@graeber-clan.de
- Add SuSEfirewall2 service file
* Wed May 20 2009 herbert@graeber-clan.de
- Split into subpackages
- Create a quasselcore user
- Add init.d script and fillup template for quasselcore
- Use /var/lib intead of /etc for configuration and data because the sqlite database
  should not be stored below /etc
- Add an empty log file
- change owner of files and directories that are used by quasselcore
* Thu Mar 26 2009 bitshuffler #suse@irc.f
- Updated to 0.4.1
* Sat Feb 21 2009 bitshuffler #suse@irc.f
- Initial RPM
